#!/usr/bin/python3

import os
import sys
from sh import rsync
from datetime import datetime

'''
The script copies an SD Card mounted on /media/pi/ 
to a folder automatically created with the same name in the 
destination drive. The destination drive's label is  defined 
in the .conf file.

1 argument:  label/name of the origin SD Card.
'''

CONFIG_FILE = '/home/pi/scripts/backup_photos.conf'
ORIGIN_DEV = sys.argv[1]
		
def create_folder(path):

	print ('attempting to create destination folder: ',path)
	if not os.path.exists(path):
		try: 
			os.mkdir(path)
			print ('Folder created.')
		except:
			print ('Folder could not be created. Stopping.')
			return
	else:
		print ('Folder already in path. Using that one instead.')



confFile = open(CONFIG_FILE,'rU') #IMPORTANT: rU Opens the file with Universal Newline Support, so \n and/or \r is recognized as a new line. 
confList = confFile.readlines()
confFile.close()


for line in confList:
	line = line.strip('\n')

	try:
		name , value = line.split('=')

		if name == 'mount folder':
			mountFolder = value
		elif name == 'destination folder':
			destDevice = value


	except ValueError:
		print ('Incorrect line format. Passing.')
		pass
# Verifying the drive is mounted
if os.path.exists(mountFolder+ORIGIN_DEV):

	destFolder = mountFolder+destDevice+'/'+ORIGIN_DEV
	create_folder(destFolder)
	print (datetime.now().strftime('%Y-%m-%d %H:%M')+' Backup process initiated...')
	
	# Comment out to delete files that are not in the origin:
	# rsync("-av", "--delete", mountFolder+ORIGIN_DEV, destFolder)
	rsync("-av", mountFolder+ORIGIN_DEV+'/', destFolder)
	
	print (datetime.now().strftime('%Y-%m-%d %H:%M')+' Backup process finished.')

else:
	print ("Error: Either the origin drive "+mountFolder+ORIGIN_DEV+" is not mounted or it has a different name.")


